Learn R Programming

NHSDataDictionaRy (version 1.2.5)

left_xl: left_xl function This function replicates the LEFT function in Excel and is utilised for left trimming of character strings

Description

left_xl function This function replicates the LEFT function in Excel and is utilised for left trimming of character strings

Usage

left_xl(text, num_char = 0)

Arguments

text

The text you want to LEFT trim

num_char

The number of characters your want to trim by

Value

Trims the text entered by the number of character parameter and returns the trimmed string

Examples

Run this code
# NOT RUN {
left_xl(text= "This is some example text", num_char = 4)

# }

Run the code above in your browser using DataLab