powered by
This function replicates the LEN function in Excel and is utilised for finding the length of character strings.
len_xl(text, ...)
The text you want to calculate the length
Function forwarding to work with the base nchar method
An integer value calculating the length of the text passed
# NOT RUN { len_xl("Guess the length of me!") # }
Run the code above in your browser using DataLab