powered by
left_xl function This function replicates the LEFT function in Excel and is utilised for left trimming of character strings
left_xl(text, num_char = 0)
The text you want to LEFT trim
The number of characters your want to trim by
Trims the text entered by the number of character parameter and returns the trimmed string
# NOT RUN { left_xl(text= "This is some example text", num_char = 4) # }
Run the code above in your browser using DataLab