powered by
This function replicates the MID function in Excel and is utilised for left trimming of character strings.
mid_xl(text, start_num = 1, num_char = 0)
The text you want to MID trim
The start number to start the trim. This needs to be numeric.
The number of characters your want to trim by. This field needs to be numeric.
The extracted text between the start_num and the num_char to produce a sub string result.
This has been included as a convenience function for working with text and string data.
# NOT RUN { mid_xl(text= "This is some example text", start_num = 6, num_char = 10) # } # NOT RUN { mid_xl(text= "This is some example text", start_num = 6, num_char = 10) # } # NOT RUN { # }
Run the code above in your browser using DataLab