powered by
This function uses the tableR parent function to return a table of elements, specifically from the NHS Data Dictionary
tableR
nhs_table_findeR(data_element_name, ...)
The data element name from NHS Data Dictionation i.e. ACCOMMODATION STATUS CODE
Function forwarding to parent function to pass additional arguments to function (e.g. title, add_zero_prefix)
A tibble (class data.frame) output from the results of the web scrape
result - the extracted national HTML code table from the element page of the NHS Data Dictionary
DictType - defaults to Not Specified if nothing passed, however allows for custom dictionary / data frame tags to be created
DttmExtracted - a date and time stamp
# NOT RUN { #Returns a tibble from tableR parent function nhs_table_findeR("ACCOMMODATION STATUS CODE", title="ACCOM_STATUS") nhs_table_findeR("accommodation status code") #Changes case to match # }
Run the code above in your browser using DataLab