This function uses the tableR parent function to return a table of elements, specifically from the OpenSafely Code List
https://www.opencodelists.org/
Usage
openSafely_listR(list_name, version = "", ...)
Arguments
list_name
The code list ID from https://www.opencodelists.org/ for which to return the National table of elements, for example
"opensafely/ace-inhibitor-medications"
version
The version of the code list if not the most recent
...
Function forwarding to parent function to pass additional arguments to function (e.g. title, add_zero_prefix)
Value
A tibble (class data.frame) output from the results of the web scrape
type - the OpenSafely type
id - the id for the OpenSafely element
bnf_code - British National Formulary - NICE guidelines code
nm - medicine type, dosage and manufacturer
Dict_type - title specified for dictionary
DttmExtracted - the date and time the code set was extracted
# NOT RUN {openSafely_listR("opensafely/ace-inhibitor-medications")
#Pull back current listopenSafely_listR("opensafely/ace-inhibitor-medications", "2020-05-19")
#Pull back list with date# }